@@ -2,7 +2,7 @@ package ReadonlyX;
 use 5.008;
 use strict;
 use warnings;
-our $VERSION = "1.01";
+our $VERSION = "1.02";
 BEGIN { *ReadonlyX:: = *Readonly:: }
 package          # hide from PAUSE
     Readonly;    # I wish...
@@ -82,7 +82,7 @@ sub _readonly {
             if $refref eq 'HASH';
         return Internals::SvREADONLY(${$_[0]}, $onoff);
     }
-    warn 'We do not know what to do with ' . $type;
+    Carp::carp 'We do not know what to do with ' . $type;
 }
 
 sub Clone(\[$@%]) {
@@ -97,17 +97,10 @@ sub Clone(\[$@%]) {
               ),
               0
     );
-    return $type eq 'SCALAR' ?
-        $$retval
-        : $type eq 'ARRAY' ?
-        wantarray ?
-        @$retval
-        : $retval
-        : $type eq 'HASH' ?
-        wantarray ?
-        %$retval
-        : $retval
-        : $retval;
+    return ($type eq 'SCALAR' ?  $$retval
+         : $type eq 'ARRAY' ?  wantarray ? @$retval : $retval
+         : $type eq 'HASH' ?  wantarray ?  %$retval : $retval
+         : $retval);
 }
 1;
 
@@ -162,15 +155,18 @@ ReadonlyX - Faster facility for creating read-only scalars, arrays, hashes
 
 =head1 Description
 
-This is a near-drop-in replacement for Readonly, the facility for creating
-non-modifiable variables. This is useful for configuration files, headers,
-etc. It can also be useful as a development and debugging tool for catching
-updates to variables that should not be changed. See the section entitled
+This is a near-drop-in replacement for L<Readonly>, the popular facility for
+creating non-modifiable variables. This is useful for configuration files,
+headers, etc. It can also be useful as a development and debugging tool for
+catching updates to variables that should not be changed.
+
+If you really need to have immutable variables in new code, use this instead
+of Readonly. You'll thank me later. See the section entitled
 L<ReadonlyX vs. Readonly> for more.
 
 =head1 Functions
 
-All of these functions are imported into your package by default.
+All of these functions can be imported into your package by name.
 
 =head2 Readonly::Scalar
 
@@ -182,13 +178,13 @@ Creates a non-modifiable scalar and assigns a value of to it. Thereafter, its
 value may not be changed. Any attempt to modify the value will cause your
 program to die.
 
-If C<$value> is a reference to a scalar, array, or hash, then this function
-will mark the scalar, array, or hash it points to as being readonly as well,
-and it will recursively traverse the structure, marking the whole thing as
-readonly.
+If the given value is a reference to a scalar, array, or hash, then this
+function will mark the scalar, array, or hash it points to as being readonly
+as well, and it will recursively traverse the structure, marking the whole
+thing as readonly.
 
-If $var is already a Readonly variable, the program will die with an error
-about reassigning Readonly variables.
+If the variable is already readonly, the program will die with an error about
+reassigning readonly variables.
 
 =head2 Readonly::Array
 
@@ -204,8 +200,8 @@ this function will mark the scalar, array, or hash it points to as being
 Readonly as well, and it will recursively traverse the structure, marking the
 whole thing as Readonly.
 
-If the array is already Readonly, the program will die with an error about
-reassigning Readonly variables.
+If the variable is already readonly, the program will die with an error about
+reassigning readonly variables.
 
 =head2 Readonly::Hash
 
@@ -226,8 +222,8 @@ function will mark the scalar, array, or hash it points to as being Readonly
 as well, and it will recursively traverse the structure, marking the whole
 thing as Readonly.
 
-If the hash is already Readonly, the program will die with an error about
-reassigning Readonly variables.
+If the variable is already readonly, the program will die with an error about
+reassigning readonly variables.
 
 =head2 Readonly::Clone
 
@@ -252,7 +248,7 @@ Here are a few very simple examples again to get you started:
 
 =head2 Scalars
 
-A plain old read-only value
+A plain old read-only value:
 
     Readonly::Scalar $a => "A string value";
 
@@ -260,6 +256,10 @@ The value need not be a compile-time constant:
 
     Readonly::Scalar $a => $computed_value;
 
+Need an undef constant? Okay:
+
+    Readonly::Scalar $a;
+
 =head2 Arrays/Lists
 
 A read-only array:
@@ -309,7 +309,7 @@ If you pass an odd number of values, the program will die:
 
 =head1 ReadonlyX vs. Readonly
 
-The original Readonly module was written for nearly twenty years ago when the
+The original Readonly module was written nearly twenty years ago when the
 built-in capability to lock variables didn't exist in perl's core. The
 original author came up with the amazingly brilliant idea to use the new (at
 the time) C<tie(...)> construct. It worked amazingly well! But it wasn't long
@@ -324,14 +324,15 @@ huge difference.
 During all this, two very distinct APIs were also designed and supported by
 Readonly. One for (then) modern perl and one written for perl 5.6. To make
 this happen, time consuming eval operations were required and the codebase
-grew so complex that fixing bugs were nearly impossible. Depending on what
-version of perl and what other modules you had installed, Readonly was three
-different modules all with different sets of quirks and bugs to fix.
+grew so complex that fixing bugs was nearly impossible. Readonly was three
+different modules all with different sets of quirks and bugs to fix depending
+on what version of perl and what other modules you had installed. It was a
+mess.
 
-Readonly was a mess. So, the original author abandoned both Readonly and
-Readonly::XS. As bugs were found, they went unfixed. The combination of speed
-and lack of development spawned several similar modules which usually did a
-better job but none were a total drop-in replacement.
+So, after the original author abandoned both Readonly and Readonly::XS, as
+bugs were found, they went unfixed. The combination of speed and lack of
+development spawned several similar modules which usually did a better job but
+none were a total drop-in replacement.
 
 Until now.
 
@@ -344,21 +345,24 @@ In short, unlike Readonly, ReadonlyX...
 
 =over
 
-=item ...does not use slow C<tie(...)> magic or eval. There should be almost no speed penalty
+=item ...does not use slow C<tie(...)> magic or eval. There shouldn't be a
+        speed penalty after making the structure immutable
 
 =item ...does not strive to work on perl versions I can't even find a working
         build of to test against
 
 =item ...has a single, clean API
 
-=item Does the right thing when it comes to deep vs. shallow structures
+=item ...does the right thing when it comes to deep vs. shallow structures
 
-=item Allows implicit undef values for scalars (Readonly inconsistantly allows
-        this for hashes and arrays but not scalars)
+=item ...allows implicit undef values for scalars (Readonly inconsistantly
+        allows this for hashes and arrays but not scalars)
 
-=item ...a lot more I can't think of right now but will add when they come to me
+=item ...a lot more I can't think of right now but will add when they come to
+        me
 
-=item is around 100 lines instead of 460ish so maintaining it will be a breeze
+=item ...is around 100 lines instead of 460ish so maintaining it will be a
+        breeze
 
 =back
 
